@@ -30,7 +30,7 @@ setClass(
 #' Clear Results
 #' 
 #' Frees all resources (local and Athena) associated with result set. It does this by removing query output in AWS S3 Bucket,
-#' stopping query execution if still runnning and removed the connection resource locally.
+#' stopping query execution if still running and removed the connection resource locally.
 #' @name dbClearResult
 #' @inheritParams DBI::dbClearResult
 #' @return \code{dbClearResult()} returns \code{TRUE}, invisibly.
@@ -152,7 +152,7 @@ setMethod(
       output <- lapply(result$ResultSet$Rows, function(x) (sapply(x$Data, function(x) if(length(x) == 0 ) NA else x)))
       
       dt <- rbindlist(output)
-      colnames(dt) <- tolower(unname(dt[1,]))
+      colnames(dt) <- as.character(unname(dt[1,]))
       rownames(dt) <- NULL
       return(dt[-1,])
     }
@@ -179,9 +179,11 @@ setMethod(
     
     if(grepl("\\.csv$",result_info$key)){
       # currently parameter data.table is left as default. If users require data.frame to be returned then parameter will be updated
-      output <- data.table::fread(File, col.names = names(Type2), colClasses = unname(Type2), showProgress = F, na.strings="")
+      output <- data.table::fread(File, col.names = names(Type2), colClasses = unname(Type2), sep = ",", showProgress = F, na.strings="")
       # formatting POSIXct: from string to POSIXct
       for (col in names(Type[Type %in% "POSIXct"])) set(output, j=col, value=as.POSIXct(output[[col]]))
+      # AWS Athena returns " values as "". Due to this "" will be reformatted back to "
+      for (col in names(Type[Type %in% "character"])) set(output, j=col, value=gsub('""' , '"', output[[col]]))
     } else{
       file_con <- file(File)
       output <- suppressWarnings(readLines(file_con))
