@@ -3,7 +3,7 @@ NULL
 
 #' AWS Athena backend dbplyr 
 #' 
-#' Create s3 implementation of \code{sql_translate_env} for AWS Athena sql translate envirnoment based off
+#' Create s3 implementation of \code{sql_translate_env} for AWS Athena sql translate environment based off
 #' \href{https://docs.aws.amazon.com/athena/latest/ug/data-types.html}{Athena Data Types} and 
 #' \href{https://docs.aws.amazon.com/athena/latest/ug/functions-operators-reference-section.html}{DML Queries, Functions, and Operators}
 #' @param con An \code{\linkS4class{AthenaConnection}} object, produced by
@@ -46,11 +46,11 @@ sql_translate_env.AthenaConnection <- function(con) {
         sql_type <- toupper(dbDataType(athena(), type)) # using toupper to keep dependencies low
         build_sql('CAST(', column, ' AS ', sql(sql_type), ')')
       },
-      as.character = sql_cast("STRING"), # using STRING from DataTypes.R conversion from R to Athena
+      as.character = sql_cast("VARCHAR"), # Varchar types are created with a length specifier (between 1 and 65535)
       as.numeric = sql_cast("DOUBLE"),
       as.double = sql_cast("DOUBLE"),
-      as.integer = sql_cast("INT"), # using INT from DataTypes.R conversion from R to Athena
-      as.integer64 = sql_cast("BIGINT"), # as.integer64 reflects bigint for athena
+      as.integer = sql_cast("INTEGER"), # https://docs.aws.amazon.com/athena/latest/ug/data-types.html#type-integer
+      as.integer64 = sql_cast("BIGINT"), # as.integer64 reflects bigint for AWS Athena
       as.Date = sql_cast("DATE"),
       as.logical = sql_cast("BOOLEAN"),
       as.raw = sql_cast("VARBINARY"),
